@@ -33,15 +33,14 @@ from yellowdog_client.model import (
     KeyringSummary,
     MachineImageFamilySummary,
     NamespacePolicy,
-    NodeStatus,
-    NodeSummary,
+    Node,
     ObjectDetail,
     ObjectPath,
     ProvisionedWorkerPool,
     ProvisionedWorkerPoolProperties,
     Task,
     TaskGroup,
-    WorkerPool,
+    Worker,
     WorkerPoolSummary,
     WorkRequirement,
     WorkRequirementSummary,
@@ -212,11 +211,13 @@ TYPE_MAP = {
     KeyringSummary: "Keyring",
     MachineImageFamilySummary: "Machine Image Family",
     NamespacePolicy: "Namespace Policy",
+    Node: "Node",
     ObjectPath: "Object Path",
     ProvisionedWorkerPool: "Provisioned Worker Pool",
     Task: "Task",
     TaskGroup: "Task Group",
     WorkRequirementSummary: "Work Requirement",
+    Worker: "Worker",
     WorkerPoolSummary: "Worker Pool",
 }
 
@@ -225,7 +226,7 @@ def print_table_core(table: str):
     """
     Core function for printing a table.
     """
-    if ARGS_PARSER.no_format:
+    if ARGS_PARSER.no_format or table.count("\n") > MAX_LINES_COLOURED_JSON:
         print(table, flush=True)
     else:
         CONSOLE_TABLE.print(table)
@@ -259,7 +260,7 @@ def compute_requirement_table(
         "Namespace",
         "Tag",
         "Status (Tgt/Exp)",
-        "ID",
+        "Compute Requirement ID",
     ]
     table = []
     for index, cr in enumerate(cr_list):
@@ -284,7 +285,14 @@ def compute_requirement_table(
 def work_requirement_table(
     wr_summary_list: List[WorkRequirementSummary],
 ) -> (List[str], List[List]):
-    headers = ["#", "Work Requirement Name", "Namespace", "Tag", "Status", "ID"]
+    headers = [
+        "#",
+        "Work Requirement Name",
+        "Namespace",
+        "Tag",
+        "Status",
+        "Work Requirement ID",
+    ]
     table = []
     for index, wr_summary in enumerate(wr_summary_list):
         namespace = "" if wr_summary.namespace is None else wr_summary.namespace
@@ -305,7 +313,7 @@ def work_requirement_table(
 def task_group_table(
     task_group_list: List[TaskGroup],
 ) -> (List[str], List[List]):
-    headers = ["#", "Task Group Name", "Status", "ID"]
+    headers = ["#", "Task Group Name", "Status", "Task Group ID"]
     table = []
     for index, task_group in enumerate(task_group_list):
         status_msg = str(task_group.status)
@@ -325,7 +333,7 @@ def task_group_table(
 
 
 def task_table(task_list: List[Task]) -> (List[str], List[List]):
-    headers = ["#", "Task Name", "Status", "ID"]
+    headers = ["#", "Task Name", "Status", "Task ID"]
     table = []
     for index, task in enumerate(task_list):
         table.append(
@@ -345,34 +353,20 @@ def worker_pool_table(
     headers = [
         "#",
         "Worker Pool Name",
+        "Namespace",
         "Type",
         "Status",
-        "Min/Run/Max",
-        "ID",
+        "Worker Pool ID",
     ]
     table = []
     for index, worker_pool_summary in enumerate(worker_pool_summaries):
-        worker_pool: WorkerPool = client.worker_pool_client.get_worker_pool_by_id(
-            worker_pool_summary.id
-        )
-        try:
-            min_nodes = str(worker_pool.properties.minNodes)
-        except:
-            min_nodes = "_"
-        try:
-            max_nodes = str(worker_pool.properties.maxNodes)
-        except:
-            max_nodes = "_"
-        node_summary: NodeSummary = worker_pool.nodeSummary
-        nodes_running = node_summary.statusCounts[NodeStatus.RUNNING]
-
         table.append(
             [
                 index + 1,
                 worker_pool_summary.name,
+                worker_pool_summary.namespace,
                 f"{worker_pool_summary.type.split('.')[-1:][0].replace('WorkerPool', '')}",
                 f"{worker_pool_summary.status}",
-                f"{min_nodes}/{nodes_running}/{max_nodes}",
                 worker_pool_summary.id,
             ]
         )
@@ -388,7 +382,7 @@ def compute_requirement_template_table(
         "Namespace",
         "Type",
         "Strategy Type",
-        "ID",
+        "Compute Requirement Template ID",
     ]
     table = []
     for index, crt_summary in enumerate(crt_summaries):
@@ -424,7 +418,7 @@ def compute_source_template_table(
         "Namespace",
         "Provider",
         "Type",
-        "ID",
+        "Compute Source Template ID",
     ]
     table = []
     for index, cst_summary in enumerate(cst_summaries):
@@ -456,7 +450,7 @@ def keyring_table(
         "#",
         "Name",
         "Description",
-        "ID",
+        "Keyring ID",
     ]
     table = []
     for index, keyring in enumerate(keyring_summaries):
@@ -480,7 +474,7 @@ def image_family_table(
         "Access",
         "Namespace",
         "OS Type",
-        "ID",
+        "Image Family ID",
     ]
     table = []
     for index, image_family in enumerate(image_family_summaries):
@@ -535,6 +529,72 @@ def instances_table(
     return headers, table
 
 
+def nodes_table(
+    nodes: List[Node],
+) -> (List[str], List[str]):
+    headers = [
+        "#",
+        "Worker Pool Name",
+        "Provider",
+        "RAM",
+        "vCPUs",
+        "Task Types",
+        "Worker Tag",
+        "# Workers",
+        "Status",
+        "Node ID",
+    ]
+    table = []
+    for index, node in enumerate(nodes):
+        if node.details is None:
+            continue
+        table.append(
+            [
+                index + 1,
+                node.worker_pool_name,
+                node.details.provider,
+                node.details.ram,
+                node.details.vcpus,
+                ", ".join(node.details.supportedTaskTypes),
+                node.details.workerTag,
+                len(node.workers),
+                node.status,
+                node.id,
+            ]
+        )
+    return headers, table
+
+
+def workers_table(
+    workers: List[Worker],
+) -> (List[str], List[str]):
+    headers = [
+        "#",
+        "Worker Pool Name",
+        "Task Types",
+        "Worker Tag",
+        "Status",
+        "Claims",
+        "Exclusive?",
+        "Worker ID",
+    ]
+    table = []
+    for index, worker in enumerate(workers):
+        table.append(
+            [
+                index + 1,
+                worker.worker_pool_name,
+                ", ".join(worker.task_types),
+                worker.worker_tag,
+                worker.status,
+                worker.claimCount,
+                worker.exclusive,
+                worker.id,
+            ]
+        )
+    return headers, table
+
+
 def allowances_table(
     allowances: List[Allowance],
 ) -> (List[str], List[str]):
@@ -546,7 +606,7 @@ def allowances_table(
         "Remaining Hrs",
         "Limit",
         "Reset",
-        "ID",
+        "Allowances ID",
     ]
     table = []
     for index, allowance in enumerate(allowances):
@@ -691,6 +751,10 @@ def print_numbered_object_list(
         headers, table = attribute_definitions_table(objects)
     elif isinstance(objects[0], NamespacePolicy):
         headers, table = namespace_policies_table(objects)
+    elif isinstance(objects[0], Node):
+        headers, table = nodes_table(objects)
+    elif isinstance(objects[0], Worker):
+        headers, table = workers_table(objects)
     else:
         table = []
         for index, obj in enumerate(objects):
@@ -731,7 +795,7 @@ def sorted_objects(
     """
     Sort objects by their 'name' property, or 'namespace' in the case of
     Namespace Storage Configurations, or 'instanceType' in the case of
-    Instances.
+    Instances, etc.
     """
     if len(objects) == 0:
         return objects
@@ -745,6 +809,13 @@ def sorted_objects(
     if isinstance(objects[0], Instance):
         return sorted(objects, key=lambda x: x.instanceType, reverse=reverse)
 
+    if isinstance(objects[0], Node):
+        # Note: worker_pool property is added dynamically in yd_list
+        return sorted(objects, key=lambda x: str(x.worker_pool_name), reverse=reverse)
+
+    if isinstance(objects[0], Worker):
+        return sorted(objects, key=lambda x: str(x.worker_pool_name), reverse=reverse)
+
     if isinstance(objects[0], AWSAvailabilityZone):
         return sorted(objects)
 
@@ -888,7 +959,7 @@ def print_compute_template_test_result(result: ComputeRequirementTemplateTestRes
             "Provider",
             "Type",
             "Region",
-            "InstanceType",
+            "Instance Type",
             "Source Name",
         ]
     ]
@@ -1044,7 +1115,7 @@ STATUS_COUNTS_NODES = [
     StatusCount("LOST"),
 ]
 
-STATUS_COUNTS_NODEACTIONS = [
+STATUS_COUNTS_NODE_ACTIONS = [
     # StatusCount("EMPTY", True),
     StatusCount("WAITING", True),
     StatusCount("EXECUTING", True),
@@ -1130,7 +1201,7 @@ def print_event(event: str, id_type: YDIDType):
             STATUS_COUNTS_NODES, event_data["nodeSummary"]["statusCounts"]
         )
         node_actions_msg = status_counts_msg(
-            STATUS_COUNTS_NODEACTIONS,
+            STATUS_COUNTS_NODE_ACTIONS,
             event_data["nodeSummary"]["actionQueueStatuses"],
             empty_msg_if_zero_total=True,
         )
